#
# spec file for package zot-registry
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%define service_name zot
%define system_user_name zot
%define executable_name zot

# https://github.com/project-zot/zot/blob/main/Makefile#L28
%define zui_version commit-3dc4992

Name:           zot-registry
Version:        2.1.5
Release:        1.1
Summary:        Scale-out production-ready vendor-neutral OCI-native container image registry
License:        Apache-2.0
URL:            https://github.com/project-zot/zot/
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
#
Source2:        https://github.com/project-zot/zui/releases/download/%{zui_version}/zui.tgz
#
Source11:       config.json
Source12:       system-user-%{system_user_name}.conf
#
Source21:       Makefile
Source22:       PACKAGING_README.md
#
BuildRequires:  awk
BuildRequires:  bash-completion
BuildRequires:  coreutils
BuildRequires:  fish
BuildRequires:  git-core
BuildRequires:  go >= 1.23
BuildRequires:  sysuser-tools
BuildRequires:  zsh

%description
Production-ready vendor-neutral OCI image registry - images stored in OCI image
format, distribution specification on-the-wire, that's it!

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       fish
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       zsh
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

tar xzf %{SOURCE2} -C ./pkg/extensions

%build
%ifarch %{ix86} s390 s390x armv7l armv7hl armv7l:armv6l:armv5tel riscv64
    export CGO_ENABLED=1
    sed -i 's/CGO_ENABLED=0/CGO_ENABLED=1/g' Makefile
%else
    export CGO_ENABLED=0
%endif

# disable modtidy target as dependency for modcheck
sed -i '/^modcheck:/ s/modcheck:.*/modcheck:/g' Makefile

# disable ui target as dependency for binary
sed -i '/^binary:.*findstring ui/d' Makefile

# disable ui target as dependency for build-metadata
sed -i '/^build-metadata:.*findstring/ s/^build-metadata:.*/build-metadata:/' Makefile

make binary

%sysusers_generate_pre %{SOURCE12} %{system_user_name} system-user-%{system_user_name}.conf

%install
# Install the binary (which has linux and the architecture in the name...
install -D -m 0755 bin/%{executable_name}* %{buildroot}/%{_bindir}/%{executable_name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{executable_name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{executable_name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{executable_name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{executable_name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{executable_name}

# Configuration file in /etc/zot/
install -D -m644 %{SOURCE11} %{buildroot}/%{_sysconfdir}/%{service_name}/config.json

# directory in /var/lib/
install -d  %{buildroot}%{_localstatedir}/lib/%{name}

# sysusers configuration file
mkdir -p %{buildroot}%{_sysusersdir}
install -m 0644 %{SOURCE12} %{buildroot}%{_sysusersdir}/

# systemd service
install -D -m 0644 examples/%{service_name}.service %{buildroot}%{_unitdir}/%{service_name}.service

%check
%{buildroot}/%{_bindir}/%{executable_name} --version 2>&1 | grep -q %{version}

%pre -f %{system_user_name}.pre
%service_add_pre %{service_name}.service

%post
%service_add_post %{service_name}.service

%preun
%service_del_preun %{service_name}.service

%postun
%service_del_postun %{service_name}.service

%files
%doc README.md examples
%license LICENSE
%{_bindir}/%{executable_name}
%{_sysusersdir}/system-user-%{system_user_name}.conf
%{_unitdir}/%{service_name}.service
%dir %{_sysconfdir}/%{service_name}/
%config(noreplace) %{_sysconfdir}/%{service_name}/config.json
%attr(-,%{system_user_name},%{system_user_name}) %{_localstatedir}/lib/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{executable_name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{executable_name}

%changelog
* Wed Jun 18 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 2.1.5:
  * chore: fix dependabot alerts (#3213)
  * chore: update zui version (#3212)
  * feat: add token auth support for event sink (#3197)
  * chore: bump github.com/olekukonko/tablewriter from 0.0.5 to
    1.0.7 (#3198)
  * fix: image retention policy to handle patterns even if metadb
    is not instantiated (#3200)
  * Fix dependabot alerts (#3188)
* Fri Jun  6 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 2.1.4:
  * Fix metrics authorization middleware bleed (#3183)
  * fix: parse public key as fallback for certificate for bearer
    authentication (#3180)
  * chore: fix dependabot alerts (#3155)
  * fix: license copyright update (#3167)
  * Revert "feat(mcp): add MCP extension support with routes and
    configur… (#3166)
  * feat(mcp): add MCP extension support with routes and
    configuration
* Fri May 23 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 2.1.3:
  * Merge commit from fork
  * fix(sync): fixed checking updates in remote tags digest (#3156)
  * chore: fix dependabot alerts (#3154)
  * chore: fix dependabot alerts (#3141)
  * feat(events): add events extension (#3045)
  * chore: fix dependabot alerts (#3127)
  * chore: update conformance badge (#3114)
  * chore: fix dependabot alerts (#3112)
  * fix: remove unneeded double locks in redis implementation of
    metadb (#3055)
  * fix: get groups claim from idtokenclaims (#3101)
  * feat(sync): use regclient for sync extension (#2903)
  * chore: fix dependabot alerts (#3099)
  * chore: fix dependabot alerts (#3084)
  * ci: update golang version to be synced to gh (#3073)
  * chore: fix dependabot alerts (#3072)
  * chore: fix dependabot alerts (#3070)
  * fix(zui): show referrers pointing to image manifests (#3053)
  * feat: handle multiple attributes (#3052)
  * chore: fix dependabot alerts (#3051)
  * feat: build windows binaries (#3047)
  * fix: bump zui version to fix minor issues with handling empty
    manifest lists and missing platform information (#3044)
  * chore: fix dependabot alerts (#3041)
  * ci: fix failures in nightly (#3042)
  * chore: Remove `VOLUME` instruction from image (#3027)
  * test: do not use the clustering feature in case of redis + s3
    storage
  * test: add scale-out clustering tests using multiple zot servers
    with with redis and S3 integration
  * chore: update image and dist specs to v1.1.1 (#3023)
  * chore: fix dependabot alerts (#3026)
  * fix: allow changing media-type when pushing an image tag
    (#3022)
  * fix: show data from docker mediatypes in search results (#3019)
  * chore: fix dependabot alerts (#3021)
  * [feat]: add support for EC/ED25519 public keys for token
    authentication (#2998)
  * chore: fix dependabot alerts (#3002)
  * Cumulative improvements for CI troubleshooting (#2996)
  * feat(htpasswd): add autoreload for htpasswd (#2933)
  * chore: fix dependabot alerts (#2991)
  * chore: fix dependabot alerts (#2988)
  * chore: fix dependabot alerts (#2978)
  * fix: Update AWS DynamoDB permission list and correct issues in
    DynamoDB examples (#2963)
  * chore: fix dependabot alerts (#2961)
  * More validation for DynamoDB cache driver cachetablename
    (#2949)
  * chore: fix dependabot alerts (#2945)
  * fix: MetaDB fixes related to Docker media types (#2934)
  * feat(ldap): allow to customize user filter (#2927)
  * redis driver for blob cache information and metadb (#2865)
  * fix(sync): fixed harbor authentication issues on '_catalog'
    endpoint (#2891)
  * chore: fix dependabot alerts (#2922)
  * feat(sync): add tag excludeRegex filter (#2906)
  * [Feat]: Support for AWS ECR Authentication with Temporary
    Tokens (#2907)
  * fix(dynamodb): properly handle ResourceInUseException for
    existing tables (#2909)
  * docs: fix ratelimit example (#2905)
  * chore: fix dependabot alerts (#2904)
* Tue Feb 25 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package zot-registry: scale-out production-ready
  vendor-neutral OCI-native container image/artifact registry
  (purely based on OCI Distribution Specification)
